/*
 * Copyright 2012 Smallcrew, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package fr.smallcrew.rest.converter;

import org.springframework.beans.BeansException;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;

import java.util.Map;
import java.util.Set;

public class DataObjectResolver implements InitializingBean, ApplicationContextAware {
  private ApplicationContext applicationContext;
  private Set<String> packagesToScan;
  private Set<String> classesToScan;

  public void setPackagesToScan(Set<String> packagesToScan) {
    this.packagesToScan = packagesToScan;
  }

  public void setClassesToScan(Set<String> classesToScan) {
    this.classesToScan = classesToScan;
  }

  @Override
  public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
    this.applicationContext = applicationContext;
  }

  @Override
  public void afterPropertiesSet() throws Exception {
    Map<String, RestConverter> converters = applicationContext.getBeansOfType(RestConverter.class);

    for (RestConverter converter : converters.values()) {
      converter.addPackage(packagesToScan);
      converter.addClasses(classesToScan);
      converter.consolidate();
    }
  }
}
