/*
 * Copyright 2012 Smallcrew, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package fr.smallcrew.rest.data;

import com.google.common.base.Objects;

import javax.xml.bind.annotation.XmlRootElement;

import static com.google.common.base.Objects.toStringHelper;

@XmlRootElement
public class Response {
  private boolean success;
  private Integer time;
  private Object value;

  public Response() {
  }

  public Response(boolean success, Integer time, Object value) {
    this.success = success;
    this.time = time;
    if (value instanceof PrimitiveValue) {
      this.value = ((PrimitiveValue) value).getValue();
    } else {
      this.value = value;
    }
  }

  public boolean isSuccess() {
    return success;
  }

  public void setSuccess(boolean success) {
    this.success = success;
  }

  public Integer getTime() {
    return time;
  }

  public void setTime(Integer time) {
    this.time = time;
  }

  public Object getValue() {
    return value;
  }

  public void setValue(Object value) {
    this.value = value;
  }

  @Override
  public boolean equals(Object o) {
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    Response other = (Response) o;
    return Objects.equal(success, other.success)
      && Objects.equal(time, other.time)
      && Objects.equal(value, other.value);
  }

  @Override
  public int hashCode() {
    return Objects.hashCode(success, time, value);
  }

  @Override
  public String toString() {
    return toStringHelper(this)
      .add("success", success)
      .add("time", time)
      .add("value", value)
      .toString();
  }
}
