/*
 * Copyright 2012 Smallcrew, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package fr.smallcrew.rest.wadl;

import fr.smallcrew.rest.data.wadl.Representation;
import fr.smallcrew.rest.data.wadl.Response;
import org.springframework.http.MediaType;

import java.lang.reflect.Method;
import java.util.Collection;

import static fr.smallcrew.rest.wadl.ApplicationBuilder.qName;

public class ResponseBuilder {
  private final Method method;
  private final Collection<MediaType> mediaTypes;

  public ResponseBuilder(Method method, Collection<MediaType> mediaTypes) {
    this.method = method;
    this.mediaTypes = mediaTypes;
  }

  public static ResponseBuilder from(Method method, Collection<MediaType> mediaTypes) {
    return new ResponseBuilder(method, mediaTypes);
  }

  public Response build() {
    Response response = null;
    Class<?> returnType = method.getReturnType();
    if (!returnType.equals(Void.TYPE)) {
      response = new Response();
      for (MediaType mediaType : mediaTypes) {
        Representation representation = new Representation();
        representation.setElement(qName(returnType));
        representation.setMediaType(mediaType.toString());
        response.getRepresentation().add(representation);
      }
    }
    return response;
  }
}
